/*
   6_Inkplate_SD_TXT example for e-radionica.com Inkplate 6
   For this example you will need only a micro USB cable, Inkplate 6 and a SD card 
   loaded with text.txt file that can be found inside folder of this example.
   Select "Inkplate 6(ESP32)" from Tools -> Board menu.
   Don't have "Inkplate 6(ESP32)" option? Follow our tutorial and add it: 
   https://e-radionica.com/en/blog/add-inkplate-6-to-arduino-ide/

   To work with SD card on Inkplate, you will need to add one extra library.
   Download and install it from here: https://github.com/e-radionicacom/Inkplate-6-SDFat-Arduino-Library
   
   You can open your own .txt file, but in order to this example works properly it should 
   not have more than 200 chars and you should name it text.txt

   This example will show you how to open .txt files and display the content of that file on Inkplate epaper display.

   Want to learn more about Inkplate? Visit www.inkplate.io
   Looking to get support? Write on our forums: http://forum.e-radionica.com/en/
   15 July 2020 by e-radionica.com
*/

#include "Inkplate.h"               //Include Inkplate library to the sketch
#include "SdFat.h"                  //Include library for SD card
Inkplate display(INKPLATE_1BIT);    //Create an object on Inkplate library and also set library into 1 Bit mode (Monochrome)
SdFile file;                        //Create SdFile object used for accessing files on SD card

void setup() {
  display.begin();                  //Init Inkplate library (you should call this function ONLY ONCE)
  display.clearDisplay();           //Clear frame buffer of display
  display.display();                //Put clear image on display

  //Init SD card. Display if SD card is init propery or not.
  if (display.sdCardInit()) {
    display.println("SD Card ok! Reading data...");
    display.partialUpdate();

    //Try to load text with max lenght of 200 chars.
    if (!file.open("/text.txt", O_RDONLY)) {            //If it fails to open, send error message to display, otherwise read the file.
      display.println("File open error");
      display.display();
    } else {
      display.clearDisplay();                           //Clear everything that is stored in frame buffer of epaper
      display.setCursor(0,0);                           //Set print position at the begining of the screen
      char text[201];                                   //Array where data from SD card is stored (max 200 chars here)
      int len = file.fileSize();                        //Read how big is file that we are opening
      if(len>200) len = 200;                            //If it's more than 200 bytes (200 chars), limit to max 200 bytes
      file.read(text, len);                             //Read data from file and save it in text array
      text[len] = 0;                                    //Put null terminating char at the and of data
      display.print(text);                              //Print data/text
      display.display();                                //Do a full refresh of display
    }
  } else {                                              //If card init was not successful, display error on screen and stop the program (using infinite loop)
    display.println("SD Card error!");
    display.partialUpdate();
    while (true);
  }
}

void loop() {
  //Nothing...
}
